@@ -3,7 +3,7 @@ use std::ops::{Add, AddAssign, Div, DivAssign, Mul, MulAssign, Sub, SubAssign};
 use num_traits::{NumCast, ToPrimitive};
 
 use crate::{
-	core::{Rect_, Size_, ValidRectType, ValidSizeType, ValidVecType, Vec},
+	core::{Rect_, Size_, ValidRectType, ValidSizeType, ValidVecType, VecN},
 	opencv_type_simple_generic,
 };
 
@@ -24,7 +24,7 @@ impl<T: ValidPointType> Point_<T> {
 	}
 
 	#[inline]
-	pub fn from_vec2(vec: Vec<T, 2>) -> Self where T: ValidVecType {
+	pub fn from_vec2(vec: VecN<T, 2>) -> Self where T: ValidVecType {
 		Self::new(vec[0], vec[1])
 	}
 
@@ -74,8 +74,8 @@ impl<T: ValidPointType> Point_<T> {
 	}
 
 	#[inline]
-	pub fn to_vec2(&self) -> Vec<T, 2> where T: ValidVecType {
-		Vec::<_, 2>::from([self.x, self.y])
+	pub fn to_vec2(&self) -> VecN<T, 2> where T: ValidVecType {
+		VecN::<_, 2>::from([self.x, self.y])
 	}
 }
 
